# -*- coding: utf-8 -*-

# FOGLAMP_BEGIN
# See: https://foglamp-foglamp-documentation.readthedocs-hosted.com
# FOGLAMP_END

import logging
import asyncio
import time

from aiohttp import web
from foglamp.common import logger
from foglamp.services.management.common import utils

__author__ = "Ashish Jabble"
__copyright__ = "Copyright (c) 2020 Dianomic Systems Inc."
__license__ = "Apache 2.0"
__version__ = "${VERSION}"

_logger = logger.setup(__name__, level=logging.INFO)


def setup(app):
    app.router.add_route('GET', '/foglamp/service/ping', ping)
    app.router.add_route('POST', '/foglamp/service/shutdown', shutdown)
    app.router.add_route('POST', '/foglamp/change', change)

    # enable cors support
    utils.enable_cors(app)


async def ping(request):
    # To avoid circular import
    from foglamp.services.management.server import Server

    since_started = time.time() - Server()._start_time
    return web.json_response({'uptime': int(since_started)})


async def shutdown(request):
    # To avoid circular import
    from foglamp.services.management.server import Server

    def schedule_shutdown():
        asyncio.ensure_future(Server().stop_app())

    try:
        Server().loop.call_later(0.5, schedule_shutdown)
    except asyncio.CancelledError:
        pass
    except Exception as ex:
        _logger.exception('Error in stopping Service, {}'.format(str(ex)))

    return web.json_response({"message": "Management service shutdown successfully."})


async def change(request):
    # To avoid circular import
    from foglamp.services.management.server import Server

    data = await request.json()
    category_name = data.get('category')
    category_value = data.get('items')
    _logger.info("For category {}, Old configuration: {} \n New configuration: {}".format(
        category_name, Server._config, category_value))
    Server._config = category_value

    return web.json_response({"message": "Reconfiguration done."})
