import sys
import json
import http.client
import argparse

from foglamp.common import logger

""" Task that calls into the API of the management service in order to trigger the configuration poll operation.

     The default schedule will execute once per day at a time between midnight and 3am local time. 
     The amount of time after midnight is taken by getting the hostid of the host and using the bottom bits 
     of that hostid to get a minute offset, between 0 and 180. 
     This is to allow for a natural staggering of requests from FogLAMP nodes. 
     By default the schedule will repeat every 24 hours. 
     This schedule can of course be altered by the user and may repeat more frequently than every 24 hours or may start at any time that is convenient for the user. 
     If the user updates the schedule it becomes the users responsibility to ensure that not all Fog LAMPs within the environment update at the same time.
"""
if __name__ == '__main__':
    _logger = logger.setup("Task [Manage]")

    parser = argparse.ArgumentParser()
    parser.add_argument("--name", required=True)
    parser.add_argument("--address", required=True)
    parser.add_argument("--port", required=True, type=int)
    namespace, args = parser.parse_known_args()
    # if --dryrun option exists in args then simply exit
    if '--dryrun' in args:
        sys.exit()
    svc_name = getattr(namespace, 'name')
    core_management_host = getattr(namespace, 'address')
    core_management_port = getattr(namespace, 'port')
    conn = http.client.HTTPConnection("{}:{}".format(core_management_host, core_management_port))
    conn.request("GET", '/foglamp/service')
    r = conn.getresponse()
    r = r.read().decode()
    jdoc = json.loads(r)
    for svc in jdoc['services']:
        if svc['type'] == "Management":
            # Call service route PUT Endpoint of management service
            conn = http.client.HTTPConnection("{}:{}".format(svc['address'], svc['service_port']))
            conn.request('PUT', '/poll')
            r = conn.getresponse()
            res = r.read().decode()
            response = json.loads(res)
            _logger.info("FogLAMP Manage Poll result...{}".format(response))
            break
